<?php


namespace Pinpoint\SocialMedia\Block;

use Magento\Framework\App\Config\ScopeConfigInterface;
use Magento\Framework\UrlInterface;
use Magento\Framework\View\Element\Template;
use Magento\Framework\View\Element\Template\Context;
use Magento\Store\Model\ScopeInterface;
use Magento\Store\Model\StoreManagerInterface;

class Social extends Template
{
    private const SOCIAL_LINK_CONFIG = "socialmedia/sociallink/";

    /**
     * Constructor
     * @param \Magento\Framework\View\Element\Template\Context $context
     * @param \Magento\Framework\App\Config\ScopeConfigInterface $scopeConfig
     * @param \Magento\Store\Model\StoreManagerInterface $storeManager
     * @param \Magento\Framework\UrlInterface $urlInterface
     * @param array $data
     */
    public function __construct(
        Context               $context,
        ScopeConfigInterface  $scopeConfig,
        StoreManagerInterface $storeManager,
        UrlInterface          $urlInterface,
        array                 $data = []
    ) {
        parent::__construct($context, $data);
        $this->_scopeConfig = $scopeConfig;
        $this->_storeManager = $storeManager;
        $this->_urlInterface = $urlInterface;
    }

    /**
     * Get Social Media Bar Enabled
     * @return bool
     */
    public function isEnable(): bool
    {
        return (bool)$this->_scopeConfig->getValue('socialmedia/sociallink/enable', ScopeInterface::SCOPE_STORE);
    }

    /**
     * Get Social Media Bar Enabled
     * @param string $socialLink
     * @return string
     */
    public function getConfig(string $socialLink): string
    {
        $config = $this->_scopeConfig->getValue(self::SOCIAL_LINK_CONFIG . $socialLink, ScopeInterface::SCOPE_STORE);
        return empty(trim($config)) ? false : $config;

    }

    /**
     * Get Facebook/Meta URL
     * @return string
     */
    public function checkFacebookLink(): string
    {
        return $this->getConfig('facebook_link');
    }

    /**
     * Get Twitter/𝕏 URL
     * @return string
     */
    public function checkTwitterLink(): string
    {
        return $this->getConfig('twitter_link');
    }

    /**
     * Get Youtube URL
     * @return string
     */
    public function checkYoutubeLink(): string
    {
        return $this->getConfig('youtube_link');
    }

    /**
     * Get Instagram URL
     * @return string
     */
    public function checkInstagramLink(): string
    {
        return $this->getConfig('instagram_link');
    }

    /**
     * Get TikTok URL
     * @return string
     */
    public function checkTiktokLink(): string
    {
        return $this->getConfig('tiktok_link');
    }

    /**
     * Get Snapchat URL
     * @return string
     */
    public function checkSnapchatLink(): string
    {
        return $this->getConfig('snapchat_link');
    }

    /**
     * Get Twitch URL
     * @return string
     */
    public function checkTwitchLink(): string
    {
        return $this->getConfig('twitch_link');
    }

    /**
     * Get Pinterest URL
     * @return string
     */
    public function checkPinterestLink(): string
    {
        return $this->getConfig('pinterest_link');
    }

    /**
     * Get base media URL
     * @return string
     */
    public function getBaseMediaUrl(): string
    {
        try {
            return $this->_storeManager->getStore()->getBaseUrl(UrlInterface::URL_TYPE_MEDIA);
        } catch (\Exception $e) {
            return false;
        }
    }
}
